import argparse

from .classes import get_all_hardlinks
from .classes import ShredDir
from .classes import ShredFile
from .logs import logger


async def main(job: argparse.Namespace) -> bool:
    """
    This is the main function for processing a shred request.
    It is called by the CLI and builds a job queue based on the arguments passed.
    """
    new_paths = set()
    logger.info(f"job type is {type(job)}")

    # Expand all directories and files, and collect mount point information
    for path in job.paths:
        if path.is_file():
            logger.info(f"Adding file: {path}")
            new_paths.add(await ShredFile(path))
        elif path.is_dir():
            if job.recursive:
                logger.info(f"Adding directory: {path}")
                new_paths.add(await ShredDir(path))
            else:
                logger.info(f"Skipping directory: {path} (try -r/--recursive)")
        else:
            raise TypeError(f"Not a file or directory: {path}")

    # Get hardlinks to subsequently unlink for all files
    job.paths = await get_all_hardlinks(new_paths)

    # Shred all physical files including hardlinks
    for path in job.paths:
        if isinstance(path, ShredFile):
            await path.shred(hash=job.exhaustive, dryrun=job.dryrun)
        elif isinstance(path, ShredDir):
            await path.shred(hash=job.exhaustive, dryrun=job.dryrun)
